Crate recall_provider

Crate recall_provider 

Recall Provider

A chain and object provider for Recall.

Re-exports

pub use fvm_ipld_encoding;
pub use fvm_shared;

Modules

json_rpc
message
object
query
response
tx
util

Traits

Client
Provides lightweight access to the Tendermint RPC. It gives access to all endpoints with the exception of the event subscription-related ones.
Provider
Provider capable of submitting queries and transactions.
TendermintClient
Get to the underlying Tendermint client if necessary, for example, to query the state of transactions.